@@ -22,7 +22,7 @@ int main(int argc, char *argv[])
         /* Read lines from input until we reach EOF */
         while((pszLine = E00ReadNextLine(hReadPtr)) != NULL)
         {
-            if (E00GetLastErrorNo() == 0)
+            if (CPLGetLastErrorNo() == 0)
                 printf("%s\n", pszLine);
             else
             {
